@@ -9,8 +9,17 @@ import (
 
 // getEndpointResolver resolves endpoints in accordance with
 // https://docs.aws.amazon.com/credref/latest/refdocs/setting-global-sts_regional_endpoints.html
-func getSTSEndpointResolver(stsRegionalEndpoints string) aws.EndpointResolverWithOptionsFunc {
+func getSTSEndpointResolver(stsRegionalEndpoints, endpointURL string) aws.EndpointResolverWithOptionsFunc {
 	return func(service, region string, options ...interface{}) (aws.Endpoint, error) {
+		if endpointURL != "" {
+			log.Println("Using custom STS endpoint " + endpointURL)
+
+			return aws.Endpoint{
+				URL:           endpointURL,
+				SigningRegion: region,
+			}, nil
+		}
+
 		if stsRegionalEndpoints == "legacy" && service == sts.ServiceID {
 			if region == "ap-northeast-1" ||
 				region == "ap-south-1" ||
